@@ -10,6 +10,10 @@
 #'
 #' @return A control object with the same elements and classes of `ref`, with
 #'   values of `x`.
+#' @param call The execution environment of a currently running function, e.g.
+#'   `caller_env()`. The function will be mentioned in error messages as the
+#'   source of the error. See the call argument of [rlang::abort()] for more
+#'   information.
 #' @keywords internal
 #' @export
 #'
@@ -20,21 +24,17 @@
 #'
 #' ctrl <- condense_control(ctrl, control_parsnip())
 #' str(ctrl)
-condense_control <- function(x, ref) {
+condense_control <- function(x, ref, ..., call = rlang::caller_env()) {
+  check_dots_empty()
   mismatch <- setdiff(names(ref), names(x))
   if (length(mismatch)) {
-    rlang::abort(
+    cli::cli_abort(
       c(
-        glue::glue(
-          "Object of class `{class(x)[1]}` cannot be coerced to ",
-          "object of class `{class(ref)[1]}`."
-        ),
-        "The following arguments are missing:",
-        glue::glue_collapse(
-          glue::single_quote(mismatch),
-          sep = ", ", last = ", and "
-        )
-      )
+        "{.obj_type_friendly {x}} cannot be coerced to {.obj_type_friendly {ref}}.",
+        "i" = "{cli::qty(mismatch)} The argument{?s} {.arg {mismatch}}
+               {?is/are} missing."
+      ),
+      call = call
     )
   }
   res <- x[names(ref)]
