@@ -4,7 +4,7 @@
 # data to formula/data objects and so on.
 
 form_form <-
-  function(object, control, env, ...) {
+  function(object, control, env, ..., call = rlang::caller_env()) {
 
     if (inherits(env$data, "data.frame")) {
       check_outcome(eval_tidy(rlang::f_lhs(env$formula), env$data), object)
@@ -27,12 +27,12 @@ form_form <-
 
     # if descriptors are needed, update descr_env with the calculated values
     if (requires_descrs(object)) {
-      data_stats <- get_descr_form(env$formula, env$data)
+      data_stats <- get_descr_form(env$formula, env$data, call = call)
       scoped_descrs(data_stats)
     }
 
     # evaluate quoted args once here to check them
-    object <- check_args(object)
+    object <- check_args(object, call = call)
 
     # sub in arguments to actual syntax for corresponding engine
     object <- translate(object, engine = object$engine)
@@ -40,40 +40,39 @@ form_form <-
     fit_call <- make_form_call(object, env = env)
 
     res <- list(
-      lvl = y_levels,
+      lvl = y_levels$lvl,
+      ordered = y_levels$ordered,
       spec = object
     )
 
-    if (control$verbosity > 1L) {
-      elapsed <- system.time(
-        res$fit <- eval_mod(
-          fit_call,
-          capture = control$verbosity == 0,
-          catch = control$catch,
-          envir = env,
-          ...
-        ),
-        gcFirst = FALSE
-      )
-    } else {
-      res$fit <- eval_mod(
-        fit_call,
-        capture = control$verbosity == 0,
-        catch = control$catch,
-        envir = env,
-        ...
-      )
-      elapsed <- list(elapsed = NA_real_)
-    }
+    time <- proc.time()
+    res$fit <- eval_mod(
+      fit_call,
+      capture = control$verbosity == 0,
+      catch = control$catch,
+      envir = env,
+      ...
+    )
+    elapsed <- proc.time() - time
     res$preproc <- list(y_var = all.vars(rlang::f_lhs(env$formula)))
-    res$elapsed <- elapsed
+    res$elapsed <- list(elapsed = elapsed, print = control$verbosity > 1L)
+
     res
   }
 
-xy_xy <- function(object, env, control, target = "none", ...) {
+xy_xy <- function(object,
+                  env,
+                  control,
+                  target = "none",
+                  ...,
+                  call = rlang::caller_env()) {
 
-  if (inherits(env$x, "tbl_spark") | inherits(env$y, "tbl_spark"))
-    rlang::abort("spark objects can only be used with the formula interface to `fit()`")
+  if (inherits(env$x, "tbl_spark") | inherits(env$y, "tbl_spark")) {
+    cli::cli_abort(
+      "spark objects can only be used with the formula interface to {.fun fit}.",
+      call = call
+    )
+  }
 
   check_outcome(env$y, object)
 
@@ -88,54 +87,42 @@ xy_xy <- function(object, env, control, target = "none", ...) {
 
   # if descriptors are needed, update descr_env with the calculated values
   if (requires_descrs(object)) {
-    data_stats <- get_descr_xy(env$x, env$y)
+    data_stats <- get_descr_xy(env$x, env$y, call = call)
     scoped_descrs(data_stats)
   }
 
   # evaluate quoted args once here to check them
-  object <- check_args(object)
+  object <- check_args(object, call = call)
 
   # sub in arguments to actual syntax for corresponding engine
   object <- translate(object, engine = object$engine)
 
-  fit_call <- make_xy_call(object, target, env)
+  fit_call <- make_xy_call(object, target, env, call)
 
-  res <- list(lvl = levels(env$y), spec = object)
+  res <- list(lvl = levels(env$y), ordered = is.ordered(env$y), spec = object)
 
-  if (control$verbosity > 1L) {
-    elapsed <- system.time(
-      res$fit <- eval_mod(
-        fit_call,
-        capture = control$verbosity == 0,
-        catch = control$catch,
-        envir = env,
-        ...
-      ),
-      gcFirst = FALSE
-    )
-  } else {
-    res$fit <- eval_mod(
-      fit_call,
-      capture = control$verbosity == 0,
-      catch = control$catch,
-      envir = env,
-      ...
-    )
-    elapsed <- list(elapsed = NA_real_)
-  }
+  time <- proc.time()
+  res$fit <- eval_mod(
+    fit_call,
+    capture = control$verbosity == 0,
+    catch = control$catch,
+    envir = env,
+    ...
+  )
+  elapsed <- proc.time() - time
 
   if (is.atomic(env$y)) {
     y_name <- character(0)
   } else {
     y_name <- colnames(env$y)
   }
-  res$preproc <- list(y_var = y_name)
-  res$elapsed <- elapsed
+  res$preproc <- list(y_var = y_name, x_names = colnames(env$x))
+  res$elapsed <- list(elapsed = elapsed, print = control$verbosity > 1L)
   res
 }
 
 form_xy <- function(object, control, env,
-                    target = "none", ...) {
+                    target = "none", ..., call = rlang::caller_env()) {
 
   encoding_info <-
     get_encoding(class(object)[1]) %>%
@@ -143,6 +130,11 @@ form_xy <- function(object, control, env,
 
   indicators <- encoding_info %>% dplyr::pull(predictor_indicators)
   remove_intercept <- encoding_info %>% dplyr::pull(remove_intercept)
+  allow_sparse_x <- encoding_info %>% dplyr::pull(allow_sparse_x)
+
+  if (allow_sparse_x && sparsevctrs::has_sparse_elements(env$data)) {
+    target <- "dgCMatrix"
+  }
 
   data_obj <- .convert_form_to_xy_fit(
     formula = env$formula,
@@ -150,7 +142,8 @@ form_xy <- function(object, control, env,
     ...,
     composition = target,
     indicators = indicators,
-    remove_intercept = remove_intercept
+    remove_intercept = remove_intercept,
+    call = call
   )
   env$x <- data_obj$x
   env$y <- data_obj$y
@@ -159,7 +152,8 @@ form_xy <- function(object, control, env,
     object = object,
     env = env, #weights!
     control = control,
-    target = target
+    target = target,
+    call = call
   )
   data_obj$y_var <- all.vars(rlang::f_lhs(env$formula))
   data_obj$x <- NULL
@@ -176,9 +170,9 @@ xy_form <- function(object, env, control, ...) {
   check_outcome(env$y, object)
 
   encoding_info <- get_encoding(class(object)[1])
-  encoding_info <- 
+  encoding_info <-
     vctrs::vec_slice(
-      encoding_info, 
+      encoding_info,
       encoding_info$mode == object$mode & encoding_info$engine == object$engine
     )
 
