@@ -105,20 +105,13 @@ translate.mars <- function(x, engine = x$engine, ...) {
 # ------------------------------------------------------------------------------
 
 #' @export
-check_args.mars <- function(object) {
+check_args.mars <- function(object, call = rlang::caller_env()) {
 
   args <- lapply(object$args, rlang::eval_tidy)
 
-  if (is.numeric(args$prod_degree) && args$prod_degree < 0)
-    rlang::abort("`prod_degree` should be >= 1.")
-
-  if (is.numeric(args$num_terms) && args$num_terms < 0)
-    rlang::abort("`num_terms` should be >= 1.")
-
-  if (!is_varying(args$prune_method) &&
-      !is.null(args$prune_method) &&
-      !is.character(args$prune_method))
-    rlang::abort("`prune_method` should be a single string value.")
+  check_number_whole(args$prod_degree, min = 1, allow_null = TRUE, call = call, arg = "prod_degree")
+  check_number_whole(args$num_terms, min = 1, allow_null = TRUE, call = call, arg = "num_terms")
+  check_string(args$prune_method, allow_empty = FALSE, allow_null = TRUE, call = call, arg = "prune_method")
 
   invisible(object)
 }
@@ -169,20 +162,22 @@ multi_predict._earth <-
     }
 
     msg <-
-      paste("Please use `keepxy = TRUE` as an option to enable submodel",
-            "predictions with `earth`.")
+      c("x" = "Please use {.code keepxy = TRUE} as an option to enable submodel
+                     predictions with earth.")
     if (any(names(object$fit$call) == "keepxy")) {
-       if (!isTRUE(object$fit$call$keepxy))
-         rlang::abort(msg)
+      if (!isTRUE(object$fit$call$keepxy)) {
+        cli::cli_abort(msg)
+      }
     } else {
-      rlang::abort(msg)
+      cli::cli_abort(msg)
     }
 
     if (is.null(type)) {
-      if (object$spec$mode == "classification")
+      if (object$spec$mode == "classification") {
         type <- "class"
-      else
+      } else {
         type <- "numeric"
+      }
     }
 
     res <-
