@@ -90,26 +90,16 @@ update.nearest_neighbor <- function(object,
   )
 }
 
-
-positive_int_scalar <- function(x) {
-  (length(x) == 1) && (x > 0) && (x %% 1 == 0)
-}
-
 # ------------------------------------------------------------------------------
 
 #' @export
-check_args.nearest_neighbor <- function(object) {
+check_args.nearest_neighbor <- function(object, call = rlang::caller_env()) {
 
   args <- lapply(object$args, rlang::eval_tidy)
 
-  if (is.numeric(args$neighbors) && !positive_int_scalar(args$neighbors)) {
-    rlang::abort("`neighbors` must be a length 1 positive integer.")
-  }
-
-  if (is.character(args$weight_func) && length(args$weight_func) > 1) {
-    rlang::abort("The length of `weight_func` must be 1.")
-  }
-
+  check_number_whole(args$neighbors, min = 0, allow_null = TRUE, call = call, arg = "neighbors")
+  check_string(args$weight_func, allow_null = TRUE, call = call, arg = "weight_func")
+  
   invisible(object)
 }
 
