@@ -22,7 +22,7 @@ predict_hazard.model_fit <- function(object,
   check_spec_pred_type(object, "hazard")
 
   if (inherits(object$fit, "try-error")) {
-    rlang::warn("Model fit failed; cannot make predictions.")
+    cli::cli_warn("Model fit failed; cannot make predictions.")
     return(NULL)
   }
 
