@@ -105,19 +105,18 @@ translate.svm_linear <- function(x, engine = x$engine, ...) {
         arg_vals$svr_eps <- 0.1
       if (!is_null(liblinear_type))
         if(!liblinear_type %in% 11:13)
-          rlang::abort(
-            paste0("The LiblineaR engine argument of `type` = ",
-                   liblinear_type,
-                   " does not correspond to an SVM regression model.")
+          cli::cli_abort(
+            "The LiblineaR engine argument {.code type = {liblinear_type}}
+             does not correspond to an SVM regression model."
           )
     } else if (x$mode == "classification") {
       if (!is_null(liblinear_type))
-        if(!liblinear_type %in% 1:5)
-          rlang::abort(
-            paste0("The LiblineaR engine argument of `type` = ",
-                   liblinear_type,
-                   " does not correspond to an SVM classification model.")
+        if (!liblinear_type %in% 1:5) {
+          cli::cli_abort(
+            "The LiblineaR engine argument of {.code type = {liblinear_type}}
+             does not correspond to an SVM classification model."
           )
+        }
     }
   }
 
@@ -140,7 +139,7 @@ translate.svm_linear <- function(x, engine = x$engine, ...) {
 # ------------------------------------------------------------------------------
 
 #' @export
-check_args.svm_linear <- function(object) {
+check_args.svm_linear <- function(object, call = rlang::caller_env()) {
   invisible(object)
 }
 
