@@ -1,8 +1,8 @@
 #' tidy methods for glmnet models
 #'
 #' `tidy()` methods for the various `glmnet` models that return the coefficients
-#' for the specific penalty value used by the `parsnip` model fit.
-#' @param x A fitted `parsnip` model that used the `glmnet` engine.
+#' for the specific penalty value used by the parsnip model fit.
+#' @param x A fitted parsnip model that used the `glmnet` engine.
 #' @param penalty A _single_ numeric value. If none is given, the value specified
 #' in the model specification is used.
 #' @param ... Not used
@@ -55,15 +55,12 @@ get_glmn_coefs <- function(x, penalty = 0.01) {
   res
 }
 
-tidy_glmnet <- function(x, penalty = NULL, ...) {
+tidy_glmnet <- function(x, penalty = NULL, ..., call = caller_env()) {
   check_installs(x$spec)
   load_libs(x$spec, quiet = TRUE, attach = TRUE)
   if (is.null(penalty)) {
-    if (isTRUE(is.numeric(x$spec$args$penalty))){
-      penalty <- x$spec$args$penalty
-    } else {
-      rlang::abort("Please pick a single value of `penalty`.")
-    }
+    penalty <- x$spec$args$penalty
   }
+  check_number_decimal(penalty, min = 0, max = 1, allow_null = TRUE, call = call)
   get_glmn_coefs(x$fit, penalty = penalty)
 }
